pymarket.statistics package
===========================

.. automodule:: pymarket.statistics
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   pymarket.statistics.maximum_aggregated_utility
   pymarket.statistics.maximum_traded_volume
   pymarket.statistics.profits
   pymarket.statistics.statistics

